#
# spec file for package python3-PyMySQL
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-PyMySQL
Version:        0.7.5
Release:        1.2
Summary:        Pure Python MySQL Driver
License:        MIT
Group:          Development/Languages/Python
Url:            https://github.com/PyMySQL/PyMySQL
Source:         https://files.pythonhosted.org/packages/source/P/PyMySQL/PyMySQL-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This package contains a pure-Python MySQL client library. Documentation on the
MySQL client/server protocol can be found here:
http://forge.mysql.com/wiki/MySQL_Internals_ClientServer_Protocol If you would
like to run the test suite, edit the config parameters in pymysql/tests/base.py.
The goal of pymysql is to be a drop-in replacement for MySQLdb and work on
CPython 2.3+, Jython, IronPython, PyPy and Python 3. We test for compatibility
by simply changing the import statements in the Django MySQL backend and running
its unit tests as well as running it against the MySQLdb and myconnpy unit tests.

%prep
%setup -q -n PyMySQL-%{version}
# remove unwanted shebang
sed -i '1 { /^#!/ d }' pymysql/tests/thirdparty/test_MySQLdb/*.py

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

#%%check
#NOTE(saschpe): Needs mysql server

%files
%defattr(-,root,root,-)
%doc CHANGELOG LICENSE README.rst 
%{python3_sitelib}/*

%changelog
* Sat Jul 23 2016 arun@gmx.de
- specfile:
  * updated url
- update to version 0.7.5:
  * Fix exception raised while importing when getpwuid() fails (#472)
  * SSCursor supports LOAD DATA LOCAL INFILE (#473)
  * Fix encoding error happen for JSON type (#477)
  * Fix test fail on Python 2.7 and MySQL 5.7 (#478)
- changes from version 0.7.4:
  * Fix AttributeError may happen while Connection.__del__ (#463)
  * Fix SyntaxError in test_cursor. (#464)
  * frozenset support for query value. (#461)
  * Start using readthedocs.io
- changes from version 0.7.3:
  * Add read_timeout and write_timeout option.
  * Support serialization customization by `conv` option.
  * Unknown type is converted by `str()`, for MySQLdb compatibility.
  * Support '%%%%' in `Cursor.executemany()`
  * Support REPLACE statement in `Cursor.executemany()`
  * Fix handling incomplete row caused by 'SHOW SLAVE HOSTS'.
  * Fix decode error when use_unicode=False on PY3
  * Fix port option in my.cnf file is ignored.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Thu Mar 24 2016 toddrme2178@gmail.com
- Initial python3 version.
* Thu Mar 24 2016 toddrme2178@gmail.com
- Update to 0.7.2
  * Fix misuse of `max_allowed_packet` parameter. (#426, #407 and #397)
  * Add %%(name)s plceholder support to `Cursor.executemany()`. (#427, thanks to
    @WorldException)
- Update to 0.7.1
  * Fix auth fail with MySQL 5.1
  * Fix escaping unicode fails on Python 2
- Update to 0.7
  * Faster binary escaping
  * Add `"_binary" prefix` to string literal for binary types.
    binary types are: `bytearray` on Python 2, `bytes` and `bytearray` on Python 3.
    This is because recent MySQL show warnings when string literal is invalid for
    connection encoding.
  * `pymysql.Binary()` returns `bytearray` on Python 2.  This is required to distinguish
    binary and string.
  * Auth plugin support.
  * no_delay option is ignored.  It will be removed in PyMySQL 0.8.
- Update to 0.6.7
  * Allow self signed certificate
  * Add max_allowed_packet option
  * Fix error when bytes in executemany
  * Support geometry type
  * Add coveralls badge to README
  * Fix some bugs relating to warnings
  * Add Cursor.mogrify() method
  * no_delay option is deprecated and True by default
  * Fix options from my.cnf overrides options from arguments
  * Allow socket like object.  (It's not feature for end users)
  * Strip quotes while reading options from my.cnf file
  * Fix encoding issue in executemany()
* Mon May 11 2015 benoit.monin@gmx.fr
- update to version 0.6.6:
    Add context manager to cursor
  * Fix can't encode blob that is not utf-8 on PY3. (regression of
    0.6.4, Thanks to @wiggzz)
- additional changes from version 0.6.4
  * Support "LOAD LOCAL INFILE".  Thanks @wraziens
  * Show MySQL warnings after execute query.
  * Fix MySQLError may be wrapped with OperationalError while
    connectiong. (#274)
  * SSCursor no longer attempts to expire un-collected rows within
    __del__, delaying termination of an interrupted program;
    cleanup of uncollected rows is left to the Connection on next
    execute, which emits a warning at that time. (#287)
  * Support datetime and time with microsecond. (#303)
  * Use surrogateescape to format bytes on Python 3.
  * OperationalError raised from connect() have information about
    original exception. (#304)
  * `init_command` now support multi statement.
  * `Connection.escape()` method now accepts second argument
    compatible to MySQL-Python.
- additional changes from version 0.6.3
  * Fixed multiple result sets with SSCursor.
  * Fixed connection timeout.
  * Fixed literal set syntax to work on Py2.6.
  * Allow for mysql negative values with 0 hour timedelta.
  * Added Connection.begin().
- additional changes from version 0.6.2
  * Fixed old password on Python 3.
  * Added support for bulk insert in Cursor.executemany().
  * Added support for microseconds in datetimes and dates before
    1900.
  * Several other bug fixes.
- additional changes from version 0.6.1
  * Added cursor._last_executed for MySQLdb compatibility
  * Cursor.fetchall() and .fetchmany now return list, not tuple
  * Allow "length of auth-plugin-data" = 0
  * Cursor.connection references connection object without weakref
- remove unwanted shebang of python files in test_MySQLdb
* Wed Oct  9 2013 dmueller@suse.com
- update to 0.6:
  - Improved Py3k support
  - Improved PyPy support
  - Added IPv6 support
  - Added Thing2Literal for Django/MySQLdb compatibility
  - Removed errorhandler
  - Fixed GC errors
  - Improved test suite
  - Many bug fixes
  - Many performance improvements
* Mon Jul 22 2013 speilicke@suse.com
- Initial version
